.. picea documentation master file, created by
   sphinx-quickstart on Mon Jul  1 14:26:26 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


**picea** ``/paɪˈsiːə/``
========================



.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   api-documentation

picea is a lightweight python module for working with (phylogenetic) trees